#
# MRDWT.R - Computes the redundant discrete wavelet transform y
#           for a 1D or 2D input signal.
#

##-----------------------------------------------------------------------------
mrdwt <- function(x, h, L) {
    .Call("do_mrdwt",
          as.matrix(x),
          as.vector(h),
          as.integer(L),
          PACKAGE="rwt")
}

